<?php
/*
* $Id: cm_header_holiday.php
* $Loc: /includes/modules/content/header/
*
* Name: HolidayMessage
* Version: 3.3.1
* Release Date: 2024-12-13
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_header_holiday extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_HEADER_HOLIDAY_';

    public function __construct() {
      parent::__construct(__FILE__);
      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }


    function execute() {
      global $language;

      $pages_array = page_selection::_get_pages(MODULE_CONTENT_HEADER_HOLIDAY_PAGES);

      if (in_array(Request::get_page(), $pages_array)) {

        $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
        include 'includes/modules/content/cm_template.php';
      }
    }

    protected function get_parameters() {
      $config_parameters = [
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Header Holiday Message Module',
          'value' => 'True',
          'desc' => 'Do you want to enable the Holiday Message content module?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Width',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'CONTENT_ALIGN' => [
          'title' => 'Content Align',
          'value' => 'text-center',
          'desc' => 'How should the content be aligned?',
          'set_func' => "Config::select_one(['text-left', 'text-center', 'text-right'], ",
        ],
        $this->config_key_base . 'PAGES' => [
          'title' => 'Pages',
          'value' => 'index.php;product_info.php;shopping_cart.php',
          'desc' => 'The pages to add the Holiday Message to.',
          'set_func' => "page_selection::_edit_pages(",
          'use_func' => 'page_selection::_show_pages',
        ],
        $this->config_key_base . 'ORDER_MAIL' => [
          'title' => 'Include Holiday Message in Order E-Mail',
          'value' => 'True',
          'desc' => 'Do you want to add the Holiday Message to the order confirmation e-mail?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];

      $lng = new language;
      foreach($lng->catalog_languages as $id => $value) {
      	$key = strtoupper($value['directory']);
        $config_parameters[$this->config_key_base . 'HEADER_' . $key] = [
            'title' => 'Holiday Title ' . $key,
            'value' => 'Holiday Title',
            'desc' => 'Holiday Message Title for ' . $key . ' language.',
            'set_func' => "cm_header_holiday::_cfg_module_textarea(",
        ];
        $config_parameters[$this->config_key_base . 'TEXT_' . $key] = [
            'title' => 'Your Holiday Text ' . $key,
            'value' => 'Place any message you want to here, you can use it for any type of notice not just holidays',
            'desc' => 'Holiday Message Text for ' . $key . ' language.',
            'set_func' => "cm_header_holiday::_cfg_module_textarea(",
        ];
      }

      return $config_parameters;
    }

    public static function _cfg_module_textarea($text, $key = '') {
      $name = (($key) ? 'configuration[' . $key . ']' : 'configuration_value');
      $textarea = new Textarea($name);
      $textarea->set('cols', '35')->set('rows', '5')->set('style', 'font: inherit;');
      $textarea->set_text($text);
      
      return $textarea;
    }

  }
